@@ -75,6 +75,7 @@ class Smiles(ABC):
             h - Show implicit hydrogens.
             !b - Disable bonds tokens.
             !x - Disable CXSMILES extension.
+            !z - Disable charge representation.
 
             Combining possible. Order independent. Another keys ignored.
         """
@@ -92,6 +93,8 @@ class Smiles(ABC):
                 kwargs['hydrogens'] = True
             if '!b' in format_spec:
                 kwargs['bonds'] = False
+            if '!z' in format_spec:
+                kwargs['charges'] = False
 
             if 'r' in format_spec:
                 kwargs['random'] = True
@@ -345,9 +348,9 @@ class MoleculeSmiles(Smiles):
                 n1 = next(x for x in adjacency[t1] if x in env)
                 n2 = next(x for x in adjacency[t2] if x in env)
                 smi[3] = '@' if self._translate_allene_sign(n, n1, n2) else '@@'
-            elif charge:
+            elif charge and kwargs.get('charges', True):
                 smi[5] = charge_str[charge]
-        elif charge:
+        elif charge and kwargs.get('charges', True):
             smi[5] = charge_str[charge]
 
         if any(smi) or atom.atomic_symbol not in organic_set or self._radicals[n] or kwargs.get('hydrogens', False):
@@ -453,6 +456,7 @@ class QuerySmiles(Smiles):
     def _format_cxsmiles(self: 'QueryContainer', order):
         hybridization = self._hybridizations
         heteroatoms = self._heteroatoms
+        masked = self._masked
         radical = self._radicals
 
         hh = ['atomProp']
@@ -465,6 +469,8 @@ class QuerySmiles(Smiles):
                 hh.append(f'{n}.hyb.{"".join(hybridization_str[x] for x in hb)}')
             if ha := heteroatoms[m]:
                 hh.append(f'{n}.het.{"".join(str(x) for x in ha)}')
+            if masked[m]:
+                hh.append(f'{n}.msk.1')
         if len(hh) > 1:
             cx.append(':'.join(hh))
         if cx:
