@@ -209,7 +209,9 @@ class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, Standar
     @cached_property
     def brutto(self) -> Dict[str, int]:
         """Counted atoms dict"""
-        return Counter(x.atomic_symbol for x in self._atoms.values())
+        c = Counter(x.atomic_symbol for x in self._atoms.values())
+        c['H'] += sum(self._hydrogens.values())
+        return dict(c)
 
     @cached_property
     def aromatic_rings(self) -> Tuple[Tuple[int, ...], ...]:
@@ -874,6 +876,17 @@ class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, Standar
             return compress(bytes(data), 9)
         return bytes(data)
 
+    @classmethod
+    def pack_len(cls, data: bytes, /, *, compressed=True) -> int:
+        """
+        Returns atoms count in molecule pack.
+        """
+        if compressed:
+            data = decompress(data)
+        if data[0] != 0:
+            raise ValueError('invalid pack header')
+        return int.from_bytes(data[1:3], 'big') >> 4
+
     @classmethod
     def unpack(cls, data: Union[bytes, memoryview], /, *, compressed=True,
                _return_pack_length=False) -> 'MoleculeContainer':
