@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2017-2021 Ramil Nugmanov <nougmanoff@protonmail.com>
+#  Copyright 2017-2022 Ramil Nugmanov <nougmanoff@protonmail.com>
 #  This file is part of chython.
 #
 #  chython is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@ from .emol import EMOLRead
 from .erxn import ERXNRead
 from .ewrite import EMDLWrite
 from .mol import MOLRead, common_isotopes
-from .parser import Parser, parse_error
+from .parser import Parser
 from .rxn import RXNRead
 from .stereo import MDLStereo
 from .read import MDLRead
