@@ -103,6 +103,36 @@ class Element(Core, ABC):
             g.flush_cache()
             g.fix_stereo()
 
+    @property
+    def x(self) -> float:
+        """
+        X coordinate of atom on 2D plane
+        """
+        try:
+            return self._graph()._plane[self._n][0]
+        except AttributeError:
+            raise IsNotConnectedAtom
+
+    @property
+    def y(self) -> float:
+        """
+        Y coordinate of atom on 2D plane
+        """
+        try:
+            return self._graph()._plane[self._n][1]
+        except AttributeError:
+            raise IsNotConnectedAtom
+
+    @property
+    def xy(self) -> Tuple[float, float]:
+        """
+        (X, Y) coordinates of atom on 2D plane
+        """
+        try:
+            return self._graph()._plane[self._n]
+        except AttributeError:
+            raise IsNotConnectedAtom
+
     @property
     def implicit_hydrogens(self) -> Optional[int]:
         try:
